package com.ibm.commerce.sample.databeans;

import com.ibm.commerce.exception.*;
import com.ibm.commerce.ras.*;
import com.ibm.commerce.beans.SmartDataBean;
import com.ibm.commerce.command.CommandContext;
import com.ibm.commerce.datatype.TypedProperty;
import com.ibm.commerce.extension.objects.OrderGiftAccessBean;

public class OrderGiftDataBean
	extends OrderGiftAccessBean implements SmartDataBean {

	private CommandContext commandContext = null;
	private TypedProperty requestProperties = null;
	private Long orderId = null;

	/**
	 * Returns the commandContext.
	 * @return CommandContext
	 */
	public CommandContext getCommandContext() {
		return commandContext;
	}

	/**
	 * Returns the requestProperties.
	 * @return TypedProperty
	 */
	public TypedProperty getRequestProperties() {
		return requestProperties;
	}

	/**
	 * Returns the orderId.
	 * @return Long
	 */
	public Long getOrderId() {
		return orderId;
	}

	/**
	 * Sets the commandContext.
	 * @param commandContext The commandContext to set
	 */
	public void setCommandContext(CommandContext commandContext) {
		this.commandContext = commandContext;
	}

	/**
	 * Sets the requestProperties.
	 * @param requestProperties The requestProperties to set
	 */
	public void setRequestProperties(TypedProperty requestProperties) {
		this.requestProperties = requestProperties;
	}

	public void setOrderId(Long orderId) {
		this.orderId = orderId;
	}

	public void populate() throws ECException {

		// if the orderId hasn't already been set then pull it from the
		// request properties.  Throw an exception if there's no id
		if (getOrderId() == null) {
			try {
				setOrderId(new Long(getRequestProperties().getString("orderId")));
			} catch (ParameterNotFoundException e) {
				throw new ECApplicationException(ECMessage._ERR_MISSING_PARAMETER,
					"OrderGiftDataBean", "populate",
					ECMessageHelper.generateMsgParms("orderId"));
			}
		}

		try {
			// load the data from the access bean
			setInitKey_ordersId(getOrderId());
			refreshCopyHelper();
		} catch (javax.naming.NamingException e) {
				throw new ECSystemException(ECMessage._ERR_NAMING_EXCEPTION, "OrderGiftDataBean", "populate");
		} catch (javax.ejb.FinderException e) {
				throw new ECSystemException(ECMessage._ERR_FINDER_EXCEPTION, "OrderGiftDataBean", "populate");
		} catch (javax.ejb.CreateException e) {
				throw new ECSystemException(ECMessage._ERR_CREATE_EXCEPTION, "OrderGiftDataBean", "populate");
		} catch (java.rmi.RemoteException e) {
				throw new ECSystemException(ECMessage._ERR_NAMING_EXCEPTION, "OrderGiftDataBean", "populate");
		}
	}
	
	public OrderGiftDataBean() {}
	
	// create a new constructor for passing access bean into databean so that JSP can work with the access bean
	public OrderGiftDataBean(OrderGiftAccessBean ab) throws com.ibm.commerce.exception.ECException {
	try {
		super.setEJBRef(ab.getEJBRef());
	}  catch (javax.ejb.FinderException e) {
 			 	throw new ECSystemException(ECMessage._ERR_CREATE_EXCEPTION,
			 	"OrderGiftDataBean", "OrderGiftDataBean(ab)");
 	} catch (javax.naming.NamingException e) {
	 	throw new ECSystemException(ECMessage._ERR_NAMING_EXCEPTION, "OrderGiftDataBean", "OrderGiftDataBean(ab)");
 	} catch (java.rmi.RemoteException e) {
	 	throw new ECSystemException(ECMessage._ERR_REMOTE_EXCEPTION, "OrderGiftDataBean", "OrderGiftDataBean(ab)");
 	} catch (javax.ejb.CreateException e) {
	 	throw new ECSystemException(ECMessage._ERR_CREATE_EXCEPTION,  "OrderGiftDataBean", "OrderGiftDataBean(ab)");
 	}
}

}
